@@ -7,6 +7,11 @@ sub test_filename {'Foo.pod'}
 sub test_main : Tests {
     my $self = shift;
 
+    if ( $^O eq 'MSWin32' ) {
+        $self->builder->skip('There is no ispell on Windows');
+        return;
+    }
+
     my $dict_file = $self->{root_dir}->child('.ispell_english');
 
     $self->tidyall(
